summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasitemlist_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasitemlist_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvasitemlist_imp.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kjsembed/qtbindings/qcanvasitemlist_imp.h b/kjsembed/qtbindings/qcanvasitemlist_imp.h
index 3f2edae1..1ec604e0 100644
--- a/kjsembed/qtbindings/qcanvasitemlist_imp.h
+++ b/kjsembed/qtbindings/qcanvasitemlist_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasItemList;
+class TTQCanvasItemList;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasItemList;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasItemList methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasItemListImp : public JSProxyImp
+class TQCanvasItemListImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -38,8 +38,8 @@ public:
Method_Last = -1
};
- QCanvasItemListImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasItemListImp();
+ TQCanvasItemListImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasItemListImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -53,7 +53,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasItemList *toQCanvasItemList( KJS::Object &object );
+ static TTQCanvasItemList *toTQCanvasItemList( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -84,7 +84,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasItemList *instance; // Temp
+ TTQCanvasItemList *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasItemList;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasItemList methods.
+ * Wrapper class for TTQCanvasItemList methods.
*
* @author Richard Moore, rich@kde.org